@@ -91,20 +91,14 @@ void pool_init_session_context(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *
 		ereport(ERROR,
 				(errmsg("failed to get process info for current process")));
 
-	/* Initialize preferred master node id. This must be done before any
-	 * statement using MASTER* macros because inside the macro,
-	 * pool_get_preferred_master_node_id() is called.
-	 */
-	pool_reset_preferred_master_node_id();
-
 	/* Choose load balancing node if necessary */
-	if (!RAW_MODE && pool_config->load_balance_mode)
+	if (pool_config->load_balance_mode)
 	{
 		node_id = select_load_balancing_node();
 	}
 	else
 	{
-		node_id = STREAM? PRIMARY_NODE_ID: MASTER_NODE_ID;
+		node_id = SL_MODE? PRIMARY_NODE_ID: MASTER_NODE_ID;
 	}
 
 	session_context->load_balance_node_id = node_id;
@@ -161,6 +155,11 @@ void pool_init_session_context(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *
 
 	/* Initialize previous pending message */
 	pool_pending_message_reset_previous_message();
+
+#ifdef NOT_USED
+	/* Initialize preferred master node id */
+	pool_reset_preferred_master_node_id();
+#endif
 }
 
 /*
@@ -240,7 +239,7 @@ void pool_unset_query_in_progress(void)
 
 	s->in_progress = false;
 
-	/* Restore where_to_send map if necessary */
+	/* Restore where_to_send map if neccessary */
 	if (s->need_to_restore_where_to_send)
 	{
 		memcpy(s->query_context->where_to_send,s->where_to_send_save, sizeof(s->where_to_send_save));
@@ -460,30 +459,6 @@ void pool_clear_sent_message_list(void)
 	}
 }
 
-/*
- * Zap query context info in sent messages to indicate that the query context
- * has been already removed.
- */
-void
-pool_zap_query_context_in_sent_messages(POOL_QUERY_CONTEXT *query_context)
-{
-	int			i;
-	POOL_SENT_MESSAGE_LIST *msglist;
-
-	msglist = &pool_get_session_context(false)->message_list;
-
-	for (i = 0; i < msglist->size; i++)
-	{
-		elog(DEBUG5, "checking zapping sent message: %p query_context: %p",
-			 &msglist->sent_messages[i], msglist->sent_messages[i]->query_context);
-		if (msglist->sent_messages[i]->query_context == query_context)
-		{
-			msglist->sent_messages[i]->query_context = NULL;
-			elog(DEBUG5, "Zap sent message: %p", &msglist->sent_messages[i]);
-		}
-	}
-}
-
 static void dump_sent_message(char *caller, POOL_SENT_MESSAGE *m)
 {
 	ereport(DEBUG1,
@@ -593,7 +568,7 @@ void pool_add_sent_message(POOL_SENT_MESSAGE *message)
 }
 
 /*
- * Find a sent message by kind and name.
+ * Get a sent message
  */
 POOL_SENT_MESSAGE *pool_get_sent_message(char kind, const char *name, POOL_SENT_MESSAGE_STATE state)
 {
@@ -616,29 +591,6 @@ POOL_SENT_MESSAGE *pool_get_sent_message(char kind, const char *name, POOL_SENT_
 	return NULL;
 }
 
-/*
- * Find a sent message by query context.
- */
-POOL_SENT_MESSAGE *
-pool_get_sent_message_by_query_context(POOL_QUERY_CONTEXT * query_context)
-{
-	int			i;
-	POOL_SENT_MESSAGE_LIST *msglist;
-
-	msglist = &pool_get_session_context(false)->message_list;
-
-	if (query_context == NULL)
-		return NULL;
-
-	for (i = 0; i < msglist->size; i++)
-	{
-		if (msglist->sent_messages[i]->query_context == query_context)
-			return msglist->sent_messages[i];
-	}
-
-	return NULL;
-}
-
 /*
  * Set message state to POOL_SENT_MESSAGE_STATE to POOL_SENT_MESSAGE_CLOSED.
  */
@@ -1393,7 +1345,7 @@ void pool_pending_message_reset_previous_message(void)
 				(errmsg("pool_pending_message_reset_previous_message: session context is not initialized")));
 		return;
 	}
-	session_context->previous_message_exists = false;
+	session_context->previous_message = NULL;
 }
 
 /*
@@ -1407,13 +1359,11 @@ void pool_pending_message_set_previous_message(POOL_PENDING_MESSAGE *message)
 				(errmsg("pool_pending_message_set_previous_message: session context is not initialized")));
 		return;
 	}
-	session_context->previous_message_exists = true;
-	memcpy(&session_context->previous_message, message, sizeof(POOL_PENDING_MESSAGE));
+	session_context->previous_message = message;
 }
 
 /*
- * Get previous message. This actually returns the address of memory. Do not
- * try to free using pool_pending_message_free_pending_message().
+ * Get previous message.
  */
 POOL_PENDING_MESSAGE *pool_pending_message_get_previous_message(void)
 {
@@ -1423,10 +1373,7 @@ POOL_PENDING_MESSAGE *pool_pending_message_get_previous_message(void)
 				(errmsg("pool_pending_message_get_previous_message: session context is not initialized")));
 		return NULL;
 	}
-	if (session_context->previous_message_exists == false)
-		return NULL;
-
-	return &session_context->previous_message;
+	return session_context->previous_message;
 }
 
 /*
@@ -1450,6 +1397,45 @@ const char *pool_pending_message_type_to_string(POOL_MESSAGE_TYPE type)
 	return pending_msg_string[type];
 }
 
+/*
+ * Check consistency the message type and backend message kind.
+ * This function is intended to be used for debugging.
+ */
+void pool_check_pending_message_and_reply(POOL_MESSAGE_TYPE type, char kind)
+{
+	/* 
+	 * Backend response message sorted by POOL_MESSAGE_TYPE
+	 */
+	static char backend_response_kind[] = {
+		'1',	/* POOL_PARSE, parse complete */
+		'2',	/* POOL_BIND, bind complete */
+		'*',	/* POOL_EXECUTE, skip checking */
+		'*',	/* POOL_DESCRIBE, skip checking */
+		'3',	/* POOL_CLOSE, close complete */
+		'Z'	/* POOL_SYNC, ready for query */
+	};
+
+	if (type < POOL_PARSE || type > POOL_SYNC)
+	{
+		ereport(DEBUG1,
+				(errmsg("pool_check_pending_message_and_reply: type out of range: %d", type)));
+		return;
+	}
+
+	if (backend_response_kind[type] == '*')
+	{
+		return;
+	}
+
+	if (backend_response_kind[type] != kind)
+	{
+		ereport(DEBUG1,
+				(errmsg("pool_check_pending_message_and_reply: type: %s but is kind: %c",
+						pool_pending_message_type_to_string(type), kind)));
+	}
+	return;
+}
+
 /*
  * Find the latest pending message having specified query context.  The
  * returned message is a pointer to the message list. So do not free it using
@@ -1521,35 +1507,6 @@ int pool_pending_message_get_target_backend_id(POOL_PENDING_MESSAGE *msg)
 	return backend_id;
 }
 
-/*
- * Get number of pending message list entries of which target backend is same as specified one.
- */
-int
-pool_pending_message_get_message_num_by_backend_id(int backend_id)
-{
-	ListCell   *cell;
-	ListCell   *next;
-	int        cnt = 0;
-
-	if (!session_context)
-	{
-		ereport(ERROR,
-				(errmsg("pool_pending_message_get_message_num_by_backend_id: session context is not initialized")));
-		return 0;
-	}
-
-	for (cell = list_head(session_context->pending_messages); cell; cell = next)
-	{
-		POOL_PENDING_MESSAGE *msg = (POOL_PENDING_MESSAGE *) lfirst(cell);
-
-		if (msg->node_ids[0] == backend_id || msg->node_ids[1] == backend_id) 
-			cnt++;
-
-		next = lnext(cell);
-	}
-	return cnt;
-}
-
 /*
  * Dump whole pending message list
  */
@@ -1630,6 +1587,7 @@ int pool_get_minor_version(void)
 	return 0;
 }
 
+#ifdef NOT_USED
 /*
  * Set preferred "master" node id.
  * Only used for SimpleForwardToFrontend.
@@ -1656,3 +1614,4 @@ void pool_reset_preferred_master_node_id(void)
 {
 	session_context->preferred_master_node_id = -1;
 }
+#endif
