@@ -109,7 +109,7 @@ typedef struct {
  */
 
 typedef enum {
-	POOL_PARSE,
+	POOL_PARSE = 0,
 	POOL_BIND,
 	POOL_EXECUTE,
 	POOL_DESCRIBE,
@@ -229,20 +229,18 @@ typedef struct {
 	List *pending_messages;
 
 	/*
-	 * The last pending message. Reset at Ready for query.  Note that this is
-	 * a shallow copy of pending message.  Once the are is reset,
-	 * previos_message_exists is set to false.
+	 * The last pending message. Reset at Ready for query.
 	 */
-	bool previous_message_exists;
-	POOL_PENDING_MESSAGE previous_message;
+	POOL_PENDING_MESSAGE *previous_message;
 
 	/* Protocol major version number */
 	int major;
 	/* Protocol minor version number */
 	int minor;
-
+#ifdef NOT_USED
 	/* Preferred "master" node id. Only used for SimpleForwardToFrontend. */
 	int preferred_master_node_id;
+#endif
 } POOL_SESSION_CONTEXT;
 
 extern void pool_init_session_context(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
@@ -271,8 +269,6 @@ extern void pool_clear_sent_message_list(void);
 extern void pool_sent_message_destroy(POOL_SENT_MESSAGE *message);
 extern POOL_SENT_MESSAGE *pool_get_sent_message(char kind, const char *name, POOL_SENT_MESSAGE_STATE state);
 extern void pool_set_sent_message_state(POOL_SENT_MESSAGE *message);
-extern void pool_zap_query_context_in_sent_messages(POOL_QUERY_CONTEXT *query_context);
-extern POOL_SENT_MESSAGE * pool_get_sent_message_by_query_context(POOL_QUERY_CONTEXT * query_context);
 extern void pool_unset_writing_transaction(void);
 extern void pool_set_writing_transaction(void);
 extern bool pool_is_writing_transaction(void);
@@ -305,16 +301,18 @@ extern void pool_pending_message_set_previous_message(POOL_PENDING_MESSAGE *mess
 extern POOL_PENDING_MESSAGE *pool_pending_message_get_previous_message(void);
 extern bool pool_pending_message_exists(void);
 extern const char *pool_pending_message_type_to_string(POOL_MESSAGE_TYPE type);
+extern void pool_check_pending_message_and_reply(POOL_MESSAGE_TYPE type, char kind);
 extern POOL_PENDING_MESSAGE *pool_pending_message_find_lastest_by_query_context(POOL_QUERY_CONTEXT *qc);
 extern int pool_pending_message_get_target_backend_id(POOL_PENDING_MESSAGE *msg);
-extern int	pool_pending_message_get_message_num_by_backend_id(int backend_id);
 extern void dump_pending_message(void);
 extern void pool_set_major_version(int major);
 extern void pool_set_minor_version(int minor);
 extern int pool_get_minor_version(void);
+#ifdef NOT_USED
 extern void pool_set_preferred_master_node_id(int node_id);
 extern int pool_get_preferred_master_node_id(void);
 extern void pool_reset_preferred_master_node_id(void);
+#endif
 
 #ifdef NOT_USED
 extern void pool_add_prep_where(char *name, bool *map);
