@@ -75,10 +75,9 @@ static int pool_get_dml_table_oid(int **oid);
 static int pool_get_dropdb_table_oids(int **oids, int dboid);
 static void pool_discard_dml_table_oid(void);
 static void pool_invalidate_query_cache(int num_table_oids, int *table_oid, bool unlink, int dboid);
-
 static int pool_get_database_oid(void);
 static void pool_add_table_oid_map(POOL_CACHEKEY *cachkey, int num_table_oids, int *table_oids);
-static void pool_reset_memqcache_buffer(bool reset_dml_oids);
+static void pool_reset_memqcache_buffer(void);
 static POOL_CACHEID *pool_add_item_shmem_cache(POOL_QUERY_HASH *query_hash, char *data, int size);
 static POOL_CACHEID *pool_find_item_on_shmem_cache(POOL_QUERY_HASH *query_hash);
 static char *pool_get_item_shmem_cache(POOL_QUERY_HASH *query_hash, int *size, int *sts);
@@ -645,7 +644,7 @@ POOL_STATUS pool_fetch_from_memory_cache(POOL_CONNECTION *frontend,
 	 * replication mode, we need to retrieve any responses from backend and
 	 * forward them to frontend.
 	 */
-	if (pool_is_doing_extended_query_message() && STREAM)
+	if (pool_is_doing_extended_query_message() && SL_MODE)
 	{
 		POOL_SESSION_CONTEXT *session_context;
 		POOL_CONNECTION *target_backend;
@@ -681,7 +680,7 @@ POOL_STATUS pool_fetch_from_memory_cache(POOL_CONNECTION *frontend,
 		send_message(frontend, 'Z', 5, (char *)&state);
 	}
 
-	if (!pool_is_doing_extended_query_message() || !STREAM)
+	if (!pool_is_doing_extended_query_message() || !SL_MODE)
 	{
 		if (pool_flush(frontend))
 		{
@@ -721,10 +720,7 @@ bool pool_is_likely_select(char *query)
 		while (*query && isspace(*query))
 			query++;
 	}
-	if (! *query)
-	{
-		return false;
-	}
+	if (! *query) { return false; }
 
 	/*
 	 * Get rid of head comment.
@@ -740,10 +736,7 @@ bool pool_is_likely_select(char *query)
 			query++;
 			do_continue = true;
 		}
-		if (do_continue)
-		{
-			continue;
-		}
+		if (do_continue) { continue; }
 
 		while (*query && !strncmp(query, "\n", 2))
 		{
@@ -943,8 +936,8 @@ bool pool_is_table_in_white_list(const char *table_name)
  * Extract table oid from INSERT/UPDATE/DELETE/TRUNCATE/
  * DROP TABLE/ALTER TABLE/COPY FROM statement.
  * Returns number of oids.
- * In case of error, returns 0 (InvalidOid).
- * oids buffer (oidsp) will be discarded by subsequent call.
+ * In case of error, returns 0(InvalidOid).
+ * oids buffer(oidsp) will be discarded by subsequent call.
  */
 int pool_extract_table_oids(Node *node, int **oidsp)
 {
@@ -1032,7 +1025,7 @@ int pool_extract_table_oids(Node *node, int **oidsp)
 		 */
 		foreach(cell, stmt->objects)
 		{
-			if (num_oids >= POOL_MAX_DML_OIDS)
+			if (num_oids > POOL_MAX_DML_OIDS)
 			{
 				ereport(LOG,
 						(errmsg("memcache: error while extracting table oids. too many oids:%d", num_oids)));
@@ -1058,7 +1051,7 @@ int pool_extract_table_oids(Node *node, int **oidsp)
 
 		foreach(cell, stmt->relations)
 		{
-			if (num_oids >= POOL_MAX_DML_OIDS)
+			if (num_oids > POOL_MAX_DML_OIDS)
 			{
 				ereport(LOG,
 						(errmsg("memcache: error while extracting table oids. too many oids:%d", num_oids)));
@@ -1086,13 +1079,6 @@ int pool_extract_table_oids(Node *node, int **oidsp)
 	oid = pool_table_name_to_oid(table);
 	if (oid > 0)
 	{
-		if (num_oids >= POOL_MAX_DML_OIDS)
-		{
-			ereport(LOG,
-					(errmsg("memcache: error while extracting table oids. too many oids:%d", num_oids)));
-			return 0;
-		}
-
 		oids[num_oids++] = pool_table_name_to_oid(table);
 		ereport(DEBUG1,
 				(errmsg("memcache: extracting table oids: table: \"%s\" oid:%d", table, oid)));
@@ -1221,7 +1207,7 @@ static void pool_discard_dml_table_oid(void)
  * using same table oid will add to the same file. If the SELECT uses
  * multiple tables, multiple table_oid_file will be created. When
  * INSERT/UPDATE/DELETE is executed, corresponding caches must be
- * deleted (cache invalidation) (when DROP TABLE, ALTER TABLE is
+ * deleted(cache invalidation) (when DROP TABLE, ALTER TABLE is
  * executed, the caches must be deleted as well). When database is
  * dropped, all caches belonging to the database must be deleted.
  */
@@ -1296,7 +1282,7 @@ int pool_get_database_oid_from_dbname(char *dbname)
 }
 
 /*
- * Add cache id (shmem case) or hash key (memcached case) to table oid
+ * Add cache id(shmem case) or hash key(memcached case) to table oid
  * map file.  Caller must hold shmem lock before calling this function
  * to avoid file extension conflict among different pgpool child
  * process.
@@ -1497,7 +1483,7 @@ void pool_discard_oid_maps_by_db(int dboid)
 }
 
 /*
- * Read cache id (shmem case) or hash key (memcached case) from table
+ * Reading cache id(shmem case) or hash key(memcached case) from table
  * oid map file according to table_oids and discard cache entries.  If
  * unlink is true, the file will be unlinked after successful cache
  * removal.
@@ -1527,8 +1513,7 @@ static void pool_invalidate_query_cache(int num_table_oids, int *table_oid, bool
 	/*
 	 * Create memqcache_oiddir/database_oid
 	 */
-	if (dboid == 0)
-	{
+	if (dboid == 0) {
 		dboid = pool_get_database_oid();
 		ereport(DEBUG1,
 			(errmsg("memcache invalidating query cache"),
@@ -1661,10 +1646,9 @@ static void pool_invalidate_query_cache(int num_table_oids, int *table_oid, bool
 }
 
 /*
- * Reset SELECT data buffers.  If reset_dml_oids is true, call
- * pool_discard_dml_table_oid() to reset table oids used in DML statements.
+ * Reset SELECT data buffers
  */
-static void pool_reset_memqcache_buffer(bool reset_dml_oids)
+static void pool_reset_memqcache_buffer(void)
 {
 	POOL_SESSION_CONTEXT * session_context;
 
@@ -1688,8 +1672,7 @@ static void pool_reset_memqcache_buffer(bool reset_dml_oids)
 		 * if the query context is still under use, we cannot discard
 		 * temporary cache.
 		 */
-		if ((SL_MODE && pool_is_doing_extended_query_message()) ||
-			can_query_context_destroy(session_context->query_context))
+		if (can_query_context_destroy(session_context->query_context))
 		{
 			ereport(DEBUG1,
 				(errmsg("memcache reset buffer"),
@@ -1705,10 +1688,7 @@ static void pool_reset_memqcache_buffer(bool reset_dml_oids)
 			session_context->query_context->temp_cache = NULL;
 		}
 	}
-
-	if (reset_dml_oids)
-		pool_discard_dml_table_oid();
-
+	pool_discard_dml_table_oid();
 	pool_tmp_stats_reset_num_selects();
 }
 
@@ -2828,11 +2808,10 @@ void pool_discard_temp_query_cache(POOL_TEMP_QUERY_CACHE *temp_cache)
 		pool_discard_buffer(temp_cache->buffer);
 	if (temp_cache->oids)
 		pool_discard_buffer(temp_cache->oids);
+	pfree(temp_cache);
 
 	ereport(DEBUG1,
 			(errmsg("pool_discard_temp_query_cache: cache discarded: %p", temp_cache)));
-
-	pfree(temp_cache);
 }
 
 /*
@@ -3184,7 +3163,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 							(errmsg("pool_handle_query_cache: temp_cache: %p", cache)));
 					pool_discard_temp_query_cache(cache);
 
-					if (STREAM && pool_is_doing_extended_query_message())
+					if (SL_MODE && pool_is_doing_extended_query_message())
 						session_context->query_context->temp_cache = NULL;
 					else
 						session_context->query_context->temp_cache = pool_create_temp_query_cache(query);
@@ -3198,7 +3177,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 			pool_stats_count_up_num_selects(1);
 
 			/* Reset temp buffer */
-			pool_reset_memqcache_buffer(true);
+			pool_reset_memqcache_buffer();
 		}
 		else
 		{
@@ -3250,7 +3229,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 	else if (is_rollback_query(node))	/* Rollback? */
 	{
 		/* Discard buffered data */
-		pool_reset_memqcache_buffer(true);
+		pool_reset_memqcache_buffer();
 	}
 	else if (is_commit_query(node))		/* Commit? */
 	{
@@ -3302,7 +3281,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 		/* Count up number of SELECT stats */
 		pool_stats_count_up_num_selects(pool_tmp_stats_get_num_selects());
 
-		pool_reset_memqcache_buffer(true);
+		pool_reset_memqcache_buffer();
 	}
 	else		/* Non cache safe queries */
 	{
@@ -3313,7 +3292,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 			{
 				/* Count up SELECT stats */
 				pool_stats_count_up_num_selects(1);
-				pool_reset_memqcache_buffer(true);
+				pool_reset_memqcache_buffer();
 			}
 			else
 			{
@@ -3336,7 +3315,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 				pool_invalidate_query_cache(num_oids, oids, true, dboid);
 				pool_discard_oid_maps_by_db(dboid);
 				pool_shmem_unlock();
-				pool_reset_memqcache_buffer(true);
+				pool_reset_memqcache_buffer();
 
 				pfree(oids);
 				ereport(DEBUG2,
@@ -3365,7 +3344,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 					pool_invalidate_query_cache(num_oids, oids, true, 0);
 					pool_shmem_unlock();
 					POOL_SETMASK(&oldmask);
-					pool_reset_memqcache_buffer(true);
+					pool_reset_memqcache_buffer();
 				}
 				else
 				{
@@ -3376,8 +3355,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 					 * if DML/DDL modifies the TABLE which SELECT uses.
 					 */
 					pool_check_and_discard_cache_buffer(num_oids, oids);
-					pool_reset_memqcache_buffer(false);
-				}
+				} 
 			}
 			else if (num_oids == 0)
 			{
@@ -3385,7 +3363,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 				 * It is also necessary to clear cache buffers in case of
 				 * no oid queries (like BEGIN, CHECKPOINT, VACUUM, etc) too.
 				 */
-				pool_reset_memqcache_buffer(true);
+				pool_reset_memqcache_buffer();
 			}
 		}
 	}
